============
 User Guide
============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    introduction
    connections
    producers
    consumers
    examples
    simple
    pools
    serialization
    failover
